<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Auth::routes();

Route::get('/','HomeController@index');
Route::post('/form/contact', 'ContactController@create')
    ->name('sendSubmission');


Route::group(['middleware' => 'auth'], function(){

    Route::get('/dashboard', 'DashboardController@index');

    Route::group(['prefix' => '/applications'], function (){

        Route::get('/pending', 'ApplicationController@showPendingUserApps')
            ->name('userPendingApps');
        Route::get('/denied', 'ApplicationController@showDeniedUserApps')
            ->name('userDeniedApps');
        Route::get('/approved', 'ApplicationController@showApprovedApps')
            ->name('userApprovedApps');


        Route::get('/staff/outstanding', 'ApplicationController@showAllPendingApps')
            ->name('staffPendingApps');

        Route::get('/staff/peer-review', 'ApplicationController@showPeerReview')
            ->name('peerReview');

        Route::get('/staff/pending-interview', 'ApplicationController@showPendingInterview')
            ->name('pendingInterview');


    });

    Route::group(['prefix' => 'apply'], function (){

        Route::get('positions/{vacancySlug}', 'ApplicationController@renderApplicationForm')
            ->name('renderApplicationForm');

    });

    Route::group(['prefix' => '/profile'], function (){

        Route::get('/settings', 'ProfileController@index');

    });


    Route::group(['prefix' => '/hr'], function (){

        Route::get('staff-members', 'UserController@showStaffMembers')
            ->name('staffMemberList');

        Route::get('players', 'UserController@showPlayers')
            ->name('registeredPlayerList');

    });

    Route::group(['prefix' => 'admin'], function (){

        Route::get('positions', 'VacancyController@index')
            ->name('showPositions');

        Route::post('positions/save', 'VacancyController@store')
            ->name('savePosition');


        Route::patch('positions/availability/{status}/{id}', 'VacancyController@updatePositionAvailability')
            ->name('updatePositionAvailability');


        Route::get('forms/builder', 'FormController@showFormBuilder')
            ->name('showFormBuilder');

        Route::post('forms/save', 'FormController@saveForm')
            ->name('saveForm');

        Route::delete('forms/destroy/{id}', 'FormController@destroy')
            ->name('destroyForm');

        Route::get('forms', 'FormController@index')
            ->name('showForms');

    });

});

//Route::get('/dashboard/login', '');

